@@ -135,6 +135,7 @@ bool stfio::importFile(
             stfio::importHDF5File(fName, ReturnData, progDlg);
             break;
         }
+#ifndef WITHOUT_ABF
         case stfio::abf: {
             stfio::importABFFile(fName, ReturnData, progDlg);
             break;
@@ -143,21 +144,29 @@ bool stfio::importFile(
             stfio::importATFFile(fName, ReturnData, progDlg);
             break;
         }
+#endif
+#ifndef WITHOUT_AXG
         case stfio::axg: {
             stfio::importAXGFile(fName, ReturnData, progDlg);
             break;
         }
+#endif
 
 #ifndef TEST_MINIMAL
         case stfio::cfs: {
             {
             int res = stfio::importCFSFile(fName, ReturnData, progDlg);
+         /*
+            // disable old Heka import - its broken and will not be fixed, use biosig instead
             if (res==-7) {
                 stfio::importHEKAFile(fName, ReturnData, progDlg);
             }
-            break;
+         */
+          break;
             }
         }
+        /*
+	// disable old Heka import - its broken and will not be fixed, use biosig instead
         case stfio::heka: {
             {
                 try {
@@ -168,6 +177,7 @@ bool stfio::importFile(
                 break;
             }
         }
+        */
 #endif // TEST_MINIMAL
 
         default:
@@ -205,10 +215,12 @@ bool stfio::exportFile(const std::string& fName, stfio::filetype type, const Rec
 {
     try {
         switch (type) {
+#ifndef WITHOUT_ABF
         case stfio::atf: {
             stfio::exportATFFile(fName, Data);
             break;
         }
+#endif
 #if (defined(WITH_BIOSIG) || defined(WITH_BIOSIG2))
         case stfio::biosig: {
             stfio::exportBiosigFile(fName, Data, progDlg);
